@@ -1,10 +1,13 @@
+//! Represents a software project.
+
 mod archive;
+mod clean;
 pub mod dto;
+mod mtime;
 
 use crate::{
     build_tool_manager::BuildToolManager,
     build_tools::{BuildStatus, BuildTool},
-    mtime::dir_mtime,
     vcs::VersionControlSystem,
 };
 use anyhow::format_err;
@@ -13,6 +16,9 @@ use chrono::{DateTime, Duration, Local, Utc};
 use std::fmt;
 use tracing::{trace, warn};
 
+use self::mtime::dir_mtime;
+
+/// Main entity.
 #[derive(Debug)]
 pub struct Project {
     /// The name of project.
@@ -43,7 +49,7 @@ impl Project {
             return None;
         }
 
-        if let ProjectStatus::ExceptClean = project_filter.status {
+        if let StatusFilter::ExceptClean = project_filter.status {
             // Ignore this project if _all_ build tools report a clean state
             if build_tools
                 .iter()
@@ -84,15 +90,6 @@ impl Project {
             mtime,
         })
     }
-
-    pub fn clean(&mut self, dry_run: bool) -> anyhow::Result<()> {
-        trace!(?self.path, "cleaning project");
-        assert!(!self.build_tools.is_empty());
-        for build_tool in self.build_tools.iter_mut() {
-            build_tool.clean_project(dry_run)?;
-        }
-        Ok(())
-    }
 }
 
 fn project_name_from(
@@ -134,23 +131,20 @@ impl fmt::Display for Project {
     }
 }
 
+/// Defines which projects to consider
 #[derive(Debug)]
 pub struct ProjectFilter {
+    /// Projects that were modified more recently than this are ignored.
     pub min_stale: Duration,
-    pub status: ProjectStatus,
-}
-
-impl Default for ProjectFilter {
-    fn default() -> Self {
-        Self {
-            min_stale: Duration::days(0),
-            status: ProjectStatus::ExceptClean,
-        }
-    }
+    /// Projects that don't satisfy the status filter are ignored
+    pub status: StatusFilter,
 }
 
+/// Filter by status reported by the [`Project`]'s build tools.
 #[derive(Debug)]
-pub enum ProjectStatus {
+pub enum StatusFilter {
+    /// Any project is considered
     Any,
+    /// All projects that are not already clean are considered
     ExceptClean,
 }
